#
# spec file for package libreoffice-openclipart
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libreoffice-openclipart
Url:            http://www.documentfoundation.org/
# We use the gengal in the headles mode; it was added in OpenOffice_org-2.2.99.221
BuildRequires:  libreoffice >= 3.3.98
# SVG import filter is in the optional package
BuildRequires:  libreoffice-filters-optional
# the system librsvg is dlopened; there is no direct dependency
BuildRequires:  librsvg
BuildRequires:  openclipart-svg
%define 	openclipart_dir %_datadir/clipart/openclipart
%define 	lo_home 	libreoffice
# LO uses ugly names for galleries (std_prefix + index + std_suffix)
# The openlipart gallery should start from the index 70
%define		gal_num_from 	70
Summary:        Extra Galleries for LibreOffice
License:        GPL-2.0+ ; LGPL-2.1+
Group:          Productivity/Office/Suite
Version:        3.5
Release:        6.3
# LO-2.x with link-to-ooo-home script is required
Requires:       libreoffice >= 3.4.98
# SVG import filter is in the optional package
Requires:       libreoffice-filters-optional >= 3.3.98
# postinstall script dependencies
%if 0%{?suse_version} > 01120
Requires(post):   coreutils
Requires(post):   grep
Requires(post):   libreoffice >= 3.4.98
Requires(postun): coreutils
Requires(postun): grep
Requires(postun): libreoffice >= 3.4.98
%endif
%if 0%{?suse_version} && 0%{?suse_version} <= 01120
PreReq:         coreutils
PreReq:         grep
PreReq:         libreoffice >= 3.4.98
%endif
# this package includes only thumbnails, the original clipart is still neeeded
%requires_eq  openclipart-svg
%if 0%{?suse_version}
Supplements:    packageand(openclipart-svg:libreoffice) packageand(openclipart-svg:OpenOffice_org)
%endif
# compat stuff
# we want to obsolete OpenOffice_org-openclipart to achieve a smooth update
Provides:       OpenOffice_org-openclipart = %version
Obsoletes:      OpenOffice_org-openclipart <= %version
Provides:       OpenOffice_org-galleries = %version
Provides:       OpenOffice_org2-galleries = %version
Obsoletes:      OpenOffice_org-galleries < %version
Obsoletes:      OpenOffice_org2-galleries < %version
Source:         libreoffice-openclipart.blacklist
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
#!ExclusiveArch:  %ix86 x86_64 ppc
ExcludeArch:    %arm ia64 s390 s390x

%description
This package contains an extensive set of extra galleries for
LibreOffice. It can be used to enrich documents with graphics arts.



%prep
%setup -T -c
cp %{S:0} .

%build
for prefix in /usr/lib /usr/lib64 ; do
    if test -x $prefix/%lo_home/program/gengal ; then
	GENGAL_BIN=$prefix/%lo_home/program/gengal
	break
    fi
done
test -z "$GENGAL_BIN" && { echo '$GENGAL_BIN not set' >&2 ; exit 1; }
#
for dir in `find -L %openclipart_dir -mindepth 1 -maxdepth 1 -type d | LC_CTYPE=C sort` ; do
	# get the gallery name from the directory name
	# and make the first character uppercase
	dirname=${dir##*/}
	gal_name=$dirname
	gal_name=`echo $gal_name | tr "_-" "  "`
	gal_name_rest=${gal_name#?}
	gal_name_first_char=${gal_name%$gal_name_rest}
	gal_name_first_char=`echo $gal_name_first_char | tr "a-z" "A-Z"`
	gal_name=$gal_name_first_char$gal_name_rest
	#
	echo "Doing gallery $gal_name..."
	#
	# add too big files to the black list (svg import is somewhat slow)
	blacklist=`mktemp /tmp/gengal.blacklist.XXXXXX`
	IFS_saved="$IFS"
IFS="
"
	for file in `find $dir -name "*.svg" | LC_CTYPE=C sort` ; do
	    test -L $file && echo "$file" >>$blacklist
	    echo size=`du -L $file | cut -f1`
	    test `du -b -L $file  | cut -f1` -gt 100000 && echo "$file" >>$blacklist
	done
	IFS="$IFS_saved"
	# add files from explicit blacklist if any
	grep "^$dirname" libreoffice-openclipart.blacklist >>$blacklist || true
	echo "Ignoring too big and problematic files:"
	cat $blacklist
	echo "Enf of the list"
	#
	# xargs is necessary because the list of files is quite long
	find $dir -name "*.svg" -print0 | \
	LC_CTYPE=C sort -z | \
	grep -z -v -f $blacklist | \
	{ xargs -0 $GENGAL_BIN -headless  --name "$gal_name" --path $RPM_BUILD_DIR/%name-%version --number-from "%gal_num_from" || exit 1; }
	rm $blacklist
done

%install
# FIXME: The stuff from this directory is linked to ooo-home by the script
#        link-to-ooo-home; so it must keep the usual OOo structure
install -m 755 -d $RPM_BUILD_ROOT%_datadir/%lo_home/share/gallery
for file in `ls sg*` ; do
    install -m 644 $file $RPM_BUILD_ROOT%_datadir/%lo_home/share/gallery
    echo "%_datadir/%lo_home/share/gallery/$file" >>$RPM_BUILD_ROOT%_datadir/%lo_home/openclipart_list.txt
done
echo "%dir %_datadir/%lo_home/"		>>$RPM_BUILD_ROOT%_datadir/%lo_home/openclipart_list.txt
echo "%dir %_datadir/%lo_home/share"		>>$RPM_BUILD_ROOT%_datadir/%lo_home/openclipart_list.txt
echo "%dir %_datadir/%lo_home/share/gallery"	>>$RPM_BUILD_ROOT%_datadir/%lo_home/openclipart_list.txt

%clean
rm -rf $RPM_BUILD_ROOT

%post
%_datadir/%lo_home/link-to-ooo-home %_datadir/%lo_home/openclipart_list.txt || true

%preun
test "$1" = "0" && %_datadir/%lo_home/link-to-ooo-home --unlink %_datadir/%lo_home/openclipart_list.txt || true

%files
%defattr(-, root, root)
%dir %_datadir/%lo_home
%_datadir/%lo_home/openclipart_list.txt
%dir %_datadir/%lo_home/share
%dir %_datadir/%lo_home/share/gallery
%_datadir/%lo_home/share/gallery/*

%changelog
* Mon Jul  9 2012 pmladek@suse.com
- maintenance update (bnc#769793, bnc#769593, MaintenanceTracker-48135)
* Thu May 24 2012 pmladek@suse.com
- add librsvg into BuildRequires; it is needed to draw the SVG pictures
  for thumbnails; the library is dlopened and there is no direct
  dependency at the moment
* Fri May 11 2012 pmladek@suse.com
- bump version to make sure that it is considered as a replacement
  of the older package
- LO-3.5 does not longer has basis3.x subdirectory; fix installation path;
  remove obsolete requires because the package should work with any LO >= 3.5
- add coreutils, grep, libreoffice as the dependency for postinstall scripts
- remove build support for openSUSE < 11.1
- remove obsolete compat symlinks for OOo
* Tue Feb 28 2012 dmueller@suse.de
- exclude from Build on ARM
* Tue Sep 13 2011 pmladek@suse.com
- maintenance update (bnc#704311, MaintenanceTracker-43152)
* Wed Aug  3 2011 pmladek@novell.com
- updated basis dir to basis3.4
- updated dependencies on LO >= 3.3.98
- fixed search for gengal binary; was moved from
  libreoffice/basis-link/program to libreoffice/program
* Fri Feb 18 2011 pmladek@suse.cz
- bumped version to make sure that it is considered as a replacement
  of the older package
* Fri Feb  4 2011 suse-beta@cboltz.de
- added error check to avoid later cryptic failure
* Thu Feb  3 2011 pmladek@suse.cz
- renamed from OpenOffice_org-openclipart to libreoffice-openclipart
- added supplements packageand(openclipart-svg:libreoffice)
  to make it installed with libreoffice (bnc#668145)
- installed files into /usr/share/libreoffice; added compat symlinks
  into the older location /usr/share/ooo3
* Tue Sep 21 2010 pmladek@suse.cz
- updated basis dir to basis3.3
- update dependencies on OOo >= 3.2.98
* Wed May 19 2010 pmladek@suse.cz
- added initial support for build on MeeGo distro
* Fri Mar 26 2010 pmladek@suse.cz
- added decorations/celticknotwork_trianglesimple_01.svg to fix build
  in openSUSE:Factory
* Mon Nov  9 2009 pmladek@suse.cz
- updated basis dir to basis3.2
- update dependencies on OOo >= 3.1.98
- added few more packages on the blacklist to fix build on openSUSE-11.2
* Mon Mar 16 2009 pmladek@suse.cz
- added back OpenOffice_org-filters-optional to BuildRequires and
  Requires because we switched to the split build in BS
* Fri Feb 27 2009 pmladek@suse.cz
- updated basis dir to basis3.1
- update dependencies on OOo >= 3.0.99
* Wed Nov 12 2008 pmladek@suse.cz
- added update-alternatives to BuildRequires for SLED10; it fixes
  an xerces-j2 dependency problem
* Tue Nov 11 2008 pmladek@suse.cz
- fixed dependency against the non-split build
* Fri Nov  7 2008 pmladek@suse.cz
- switched to the openclipart-svg sources
- added OpenOffice_org-filters-optional to BuildRequires and Requires;
  it includes the SVG import filter for OOo
- added too big and some problematic files on the blacklist
- updated to the version 3 to be in sync with OpenOffice_org
* Fri Aug 15 2008 pmladek@suse.cz
- added Supplements: packageand(openclipart:OpenOffice_org) (bnc#168589)
* Mon Jul 21 2008 pmladek@suse.cz
- updated for OOo-3.0 (prefixes, dependency)
* Tue Jul 24 2007 pmladek@suse.cz
- split from the OpenOffice_org-2.2.99.221 source package [n#284980]
- renamed from OpenOffice_org-galleries to OpenOffice_org-openclipart
- used version 2 (should work for all OOo-2.x packages)
- used gengal in the headless mode; it was a feature added in
  OpenOffice_org-2.2.99.221
